pub struct MapOverTextAgent { /* private fields */ }Expand description
Iterates a single agent over each item in a state list.
Reads state[list_key], runs agent per item (setting state[item_key]),
collects results into state[output_key].
Implementations
Sourceimpl MapOverTextAgent
impl MapOverTextAgent
Sourcepub fn new(
name: impl Into<String>,
agent: Arc<dyn TextAgent>,
list_key: impl Into<String>,
) -> Self
pub fn new( name: impl Into<String>, agent: Arc<dyn TextAgent>, list_key: impl Into<String>, ) -> Self
Create a new map-over agent that iterates over a list in state.
Sourcepub fn item_key(self, key: impl Into<String>) -> Self
pub fn item_key(self, key: impl Into<String>) -> Self
Set the state key for the current item (default: “_item”).
Sourcepub fn output_key(self, key: impl Into<String>) -> Self
pub fn output_key(self, key: impl Into<String>) -> Self
Set the state key for the output list (default: “_results”).