pub struct StaticToolset { /* private fields */ }Expand description
A simple toolset backed by a fixed list of tools.
Implementations
Sourceimpl StaticToolset
impl StaticToolset
Sourcepub fn new(tools: Vec<Arc<dyn ToolFunction>>) -> Self
pub fn new(tools: Vec<Arc<dyn ToolFunction>>) -> Self
Create a new static toolset from a list of tools.
Sourcepub fn filter_by_name(&self, names: &[&str]) -> Self
pub fn filter_by_name(&self, names: &[&str]) -> Self
Create a new toolset containing only tools whose names are in names.