pub struct ExampleTool { /* private fields */ }Expand description
Tool that adds few-shot examples to the LLM request.
This is not a callable tool — it modifies the LLM request to include example conversations that guide the model’s behavior.
Implementations
Sourceimpl ExampleTool
impl ExampleTool
Sourcepub fn from_provider(provider: &dyn ExampleProvider) -> Self
pub fn from_provider(provider: &dyn ExampleProvider) -> Self
Create from an example provider.
Sourcepub fn process_llm_request(&self, request: &mut LlmRequest)
pub fn process_llm_request(&self, request: &mut LlmRequest)
Add example instructions to the LLM request.
Appends the examples to the system instruction as formatted input/output pairs.