pub struct ExitLoopTool;Expand description
Tool that signals a loop agent to exit its loop.
When the model calls this tool, the loop agent’s escalate flag is set, causing it to break out of the current iteration.
Implementations
Sourceimpl ExitLoopTool
impl ExitLoopTool